﻿using System;
using GrapeCity.Documents.Word;
using System.Diagnostics;

namespace ArticleWithGcWord
{
    class Program
    {
        static void Main(string[] args)
        {
            GcWordDocument doc = new GcWordDocument();
            // Add the first title to the document:
            // The primary way of manipulating objects in GcWord is via ranges. 
            //Get the range of first section of the document body in which we will add title to the document.
            Range range = doc.Body.Sections.First.GetRange();
            Paragraph p = range.Paragraphs.Add("Introduction");
            p.Format.Alignment = ParagraphAlignment.Center;
            // Get the range on the paragraph that we've just added:
            Range r = p.GetRange();
            // A Run is a contiguous fragment of a document with uniform formatting.
            // In our case, we have only one run so far, get it:
            Run run = r.Runs.First;
            // Set the size of the font on the whole run:
            run.Font.Size = 20;
            run.Font.Name = "Arial";

            //Add second title to the document
            p = range.Paragraphs.Add("The Importance of Wetlands");
            p.Format.Alignment = ParagraphAlignment.Center;
            r = p.GetRange();
            run = r.Runs.Last;
            run.Font.Size = 16;
            run.Font.Name = "Arial";

            //Set style for rest of the  paragraphs in the document
            var pStyle = doc.Styles.Add("par style 1", StyleType.Paragraph);
            pStyle.ParagraphFormat.Indentation.FirstLineIndent = 36;
            pStyle.ParagraphFormat.Alignment = ParagraphAlignment.Distribute;

            //Set style for characters in the document
            var cStyle = doc.Styles.Add("char style 1", StyleType.Character);
            cStyle.Font.Size = 9;

            //Get text for paragraphs from a text file
            string line;
            int counter = 0;
            System.IO.StreamReader file = new System.IO.StreamReader(@"TheImportanceOfWetlands.txt");
            //Add a paragraph and set paragraph style on it
            p = doc.Body.Sections.First.GetRange().Paragraphs.Add();
            p.Style = pStyle;
            //Read the text file line by line and add to the last run in the document
            while ((line = file.ReadLine()) != null && line != @"\n")
            {
                if (string.IsNullOrEmpty(line))
                {
                    p = doc.Body.Sections.First.GetRange().Paragraphs.Add();
                    p.Style = pStyle;
                }
                run = p.GetRange().Runs.Add(line);
                run.Style = cStyle;

                counter++;
            }
            //Save the document
            doc.Save("ImportanceOfWetlands.docx", DocumentType.Document);

            //Open the document
            ProcessStartInfo psi = new ProcessStartInfo() { FileName = "ImportanceOfWetlands.docx", UseShellExecute = true };
            Process.Start(psi);
        }
    }
}
